@@ -3,7 +3,7 @@ from pathlib import Path
 from typing import Optional
 
 from pydantic import BaseModel
-from typer import Argument
+from typer import Argument, Option
 from yaml import safe_load
 
 from deckz.cli import app
@@ -13,11 +13,15 @@ from deckz.paths import GlobalPaths
 
 @app.command()
 def issue(
-    title: str, body: Optional[str] = Argument(None), path: Path = Path(".")
+    title: str = Argument(..., help="Title of the issue"),
+    body: Optional[str] = Argument(None, help="Body of the issue"),
+    workdir: Path = Option(
+        Path("."), help="Path to move into before running the command"
+    ),
 ) -> None:
     """Create an issue on GitHub."""
     logger = getLogger(__name__)
-    config = IssuesConfig.from_global_paths(GlobalPaths.from_defaults(path))
+    config = IssuesConfig.from_global_paths(GlobalPaths.from_defaults(workdir))
     api = GitHubAPI(config.api_key)
     url = api.create_issue(config.owner, config.repo, title, body, config.project)
     logger.info(
