@@ -25,14 +25,15 @@ class GlobalPaths:
     git_dir: Path = attrib(converter=_path_converter)
     settings: Path = attrib(converter=_path_converter)
     shared_dir: Path = attrib(converter=_path_converter)
+    figures_dir: Path = attrib(converter=_path_converter)
     shared_img_dir: Path = attrib(converter=_path_converter)
     shared_code_dir: Path = attrib(converter=_path_converter)
     shared_latex_dir: Path = attrib(converter=_path_converter)
-    shared_tikz_dir: Path = attrib(converter=_path_converter)
     shared_tikz_pdf_dir: Path = attrib(converter=_path_converter)
-    shared_plt_dir: Path = attrib(converter=_path_converter)
     shared_plt_pdf_dir: Path = attrib(converter=_path_converter)
     templates_dir: Path = attrib(converter=_path_converter)
+    plt_dir: Path = attrib(converter=_path_converter)
+    tikz_dir: Path = attrib(converter=_path_converter)
     yml_templates_dir: Path = attrib(converter=_path_converter)
     template_global_config: Path = attrib(converter=_path_converter)
     template_user_config: Path = attrib(converter=_path_converter)
@@ -58,6 +59,7 @@ class GlobalPaths:
         git_dir = get_git_dir(current_dir)
         shared_dir = git_dir / "shared"
         templates_dir = git_dir / "templates"
+        figures_dir = git_dir / "figures"
         yml_templates_dir = templates_dir / "yml"
         jinja2_dir = templates_dir / "jinja2"
         user_config_dir = Path(appdirs_user_config_dir(app_name))
@@ -69,9 +71,10 @@ class GlobalPaths:
             yml_templates_dir=yml_templates_dir,
             jinja2_dir=jinja2_dir,
             user_config_dir=user_config_dir,
-            shared_plt_dir=shared_dir / "plt-src",
+            figures_dir=figures_dir,
+            plt_dir=figures_dir / "plt",
             shared_plt_pdf_dir=shared_dir / "plt",
-            shared_tikz_dir=shared_dir / "tikz-src",
+            tikz_dir=figures_dir / "tikz",
             shared_tikz_pdf_dir=shared_dir / "tikz",
             settings=git_dir / "settings.yml",
             shared_img_dir=shared_dir / "img",
